@@ -14,6 +14,7 @@ class Config:
     tornado_cookie_name = f"{name}-user"
     tornado_cookie_secret = f"it was dark and stormy night for {name}"
     tornado_login_url = "/login"
+    login_page = "login.html"
     static_path = resource_filename("liteblue.apps", "static")
     procedures = ".procedures"
 
@@ -30,5 +31,7 @@ class Config:
     db_url = os.getenv("DB_URL", f"sqlite:///{name}.db")
     connection_kwargs = SQLITE_CONNECT_ARGS
 
-    redis_url = None
-    redis_topic = f"{name}-broadcast"
+    redis_url = None  # if mutiple hosts or worker this is how they communicate
+    redis_topic = f"{name}-broadcast"  # topic for all broadcasts
+    redis_queue = f"{name}-work"  # queue for remote workers
+    redis_workers = 0  # if not 0 then redis workers waiting on redis_queue
