@@ -14,7 +14,7 @@ def annotation_to_str(annotation):
         return annotation
     if inspect.isclass(annotation):
         return annotation.__name__
-    if isinstance(annotation, typing._GenericAlias):  # pylint: disable=W0212
+    if isinstance(annotation, typing._BaseGenericAlias):  # pylint: disable=W0212
         return str(annotation)
     if inspect.isfunction(annotation):
         return annotation.__name__
