@@ -94,14 +94,14 @@ class BroadcastMixin:
             client.ping(msg)
 
     @classmethod
-    def send(cls, data, user_ids):
+    def send(cls, data, user_ids=None):
         """ does the actual sending to all _clients_ """
         message = json_utils.dumps(data)
         LOGGER.debug("sending: %s", message)
         for client in cls._clients_:
             if user_ids is None:
                 client.queue.put_nowait(message)
-            elif client.current_user["id"] in user_ids:
+            elif client.current_user and client.current_user["id"] in user_ids:
                 client.queue.put_nowait(message)
 
     @classmethod
